#
# spec file for package gromacs
#
# Copyright (c) 2013,2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           gromacs
Version:        5.0.2
Release:        4.28
Summary:        Molecular Dynamics Package
License:        GPL-2.0+
Group:          Productivity/Scientific/Chemistry
Url:            http://www.gromacs.org
Source0:        ftp://ftp.gromacs.org/pub/gromacs/gromacs-%{version}.tar.gz
Source1:        ftp://ftp.gromacs.org/pub/manual/manual-%{version}.pdf
Source2:        http://gerrit.gromacs.org/download/regressiontests-%{version}.tar.gz

BuildRequires:  gcc-c++
BuildRequires:  cmake >= 2.8.8
BuildRequires:  fdupes
BuildRequires:  openmpi-devel
%if %{defined fedora}
BuildRequires:  pkgconfig
%else
BuildRequires:  pkg-config
%endif
BuildRequires:  pkgconfig(fftw3)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
GROMACS is a versatile and extremely well optimized package to perform
molecular dynamics computer simulations and subsequent trajectory analysis.
It is developed for biomolecules like proteins, but the extremely high
performance means it is used also in several other field like polymer chemistry
and solid state physics.

%package devel
Summary:        Molecular dynamics package
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
GROMACS is a versatile and extremely well optimized package to perform
molecular dynamics computer simulations and subsequent trajectory analysis.
It is developed for biomolecules like proteins, but the extremely high
performance means it is used also in several other field like polymer chemistry
and solid state physics.

This package contains development libraries and header for GROMACS

%package bash
Summary:    Bash completion for Gromacs
Group:      Productivity/Other
Requires:   %{name} = %{version}-%{release}
Requires:   bash-completion
BuildArch:  noarch

%description bash
GROMACS is a versatile and extremely well optimized package to perform
molecular dynamics computer simulations and subsequent trajectory analysis.
It is developed for biomolecules like proteins, but the extremely high
performance means it is used also in several other field like polymer chemistry
and solid state physics.

This package contains bash completion support for gromacs.

%package doc
Summary:    Documentation for Gromacs
Group:      Productivity/Scientific/Chemistry
Requires:   %{name} = %{version}-%{release}
BuildArch:  noarch

%description doc
GROMACS is a versatile and extremely well optimized package to perform
molecular dynamics computer simulations and subsequent trajectory analysis.
It is developed for biomolecules like proteins, but the extremely high
performance means it is used also in several other field like polymer chemistry
and solid state physics.

This package contains documentation for gromacs.

%package openmpi
Summary:        Molecular dynamics package
Group:          Productivity/Scientific/Chemistry
Requires:       %{name} = %{version}

%description openmpi
GROMACS is a versatile and extremely well optimized package to perform
molecular dynamics computer simulations and subsequent trajectory analysis.
It is developed for biomolecules like proteins, but the extremely high
performance means it is used also in several other field like polymer chemistry
and solid state physics.

This package contains the openmpi version of GROMACS.

%prep
%setup -q
tar -xzf %{S:2}

%build
%ifarch i386 x86_64
#increse to SSE4.1, AVX_128_FMA, AVX_256 when possible
%define acce SSE2
%else
%define acce None
%endif
mkdir nompi openmpi
cd nompi
# note about rpath
# gromacs' cmake has too rpath much auto-magin, just
# force to skip it (CMAKE_SKIP_RPATH=1) and use 
# LD_LIBRARY_PATH for make check
cmake \
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
  -DCMAKE_VERBOSE_MAKEFILE=TRUE \
  -DCMAKE_BUILD_TYPE=Release \
  -DCMAKE_C_FLAGS_RELEASE:STRING="%{optflags} -fno-strict-aliasing" \
  -DCMAKE_CXX_FLAGS_RELEASE:STRING="%{optflags}" \
  -DCMAKE_SKIP_RPATH=1 \
  -DGMX_SIMD=%{acce} \
  -DGMX_MPI=OFF \
  -DGMX_THREAD_MPI=ON \
  -DGMX_SYMLINK_OLD_BINARY_NAMES=OFF \
  -DGMX_OPENMP=ON \
  -DREGRESSIONTEST_PATH="$PWD/../regressiontests-%{version}" \
  -DGMX_LIB_INSTALL_DIR=%{_lib} \
  ..
make %{?_smp_mflags}
cd ../openmpi

%if %{defined fedora}
%{_openmpi_load}
%endif
cmake \
  -DCMAKE_INSTALL_PREFIX=/usr \
  -DCMAKE_VERBOSE_MAKEFILE=TRUE \
  -DCMAKE_BUILD_TYPE=Release \
  -DCMAKE_C_FLAGS_RELEASE:STRING="%{optflags} -fno-strict-aliasing" \
  -DCMAKE_CXX_FLAGS_RELEASE:STRING="%{optflags}" \
  -DCMAKE_SKIP_RPATH=1 \
  -DGMX_SIMD=%{acce} \
  -DGMX_BUILD_MDRUN_ONLY=ON \
  -DGMX_MPI=ON \
  -DGMX_SYMLINK_OLD_BINARY_NAMES=OFF \
  -DGMX_OPENMP=ON \
  -DGMX_LIB_INSTALL_DIR=%{_lib} \
  ..
make %{?_smp_mflags}

%install
make -C nompi install DESTDIR=%{buildroot}
make -C openmpi install DESTDIR=%{buildroot}
%fdupes %{buildroot}%{_prefix}

#not need when installed in /usr
rm -f %{buildroot}%{_bindir}/GMXRC*
# Move bash completion file to correct location
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d
#concatenate all gmx-completion*, starting with gmx-completion.bash (fct defs)
cat %{buildroot}%{_bindir}/gmx-completion{,?*}.bash > %{buildroot}%{_sysconfdir}/bash_completion.d/gromacs
rm -f %{buildroot}%{_bindir}/gmx-completion*

cp %{S:1} %{buildroot}%{_datadir}/gromacs

%check
%if %{defined fedora}
%{_openmpi_unload}
%endif
LD_LIBRARY_PATH=%{buildroot}/%{_libdir} make -C nompi %{?_smp_mflags} check

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%{_bindir}/*
%exclude %{_bindir}/*_mpi
%{_datadir}/gromacs
%exclude %{_datadir}/gromacs/html
%exclude %{_datadir}/gromacs/template
%exclude %{_datadir}/gromacs/*.pdf
%{_libdir}/lib*.so.*
%{_mandir}/man1/*
%{_mandir}/man7/*

%files doc
%defattr(-,root,root,-)
%doc %{_datadir}/gromacs/html
%doc %{_datadir}/gromacs/*.pdf

%files openmpi
%defattr(-,root,root,-)
%{_bindir}/*_mpi

%files devel
%defattr(-,root,root)
%{_datadir}/gromacs/template
%{_includedir}/gromacs/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*

%files bash
%defattr(-,root,root,-)
%config %{_sysconfdir}/bash_completion.d/gromacs

%changelog
* Wed Oct  8 2014 junghans@votca.org
- version bump to 5.0.2
- Details: http://www.gromacs.org/About_Gromacs/Release_Notes/Versions_5.0.x
* Sat Sep  6 2014 junghans@votca.org
- version bump to 5.0.1
- Details: http://www.gromacs.org/About_Gromacs/Release_Notes/Versions_5.0.x
* Mon Feb 10 2014 junghans@votca.org
- added %%check
* Sun Feb  9 2014 junghans@votca.org
- version bumped to 4.6.5
- fix GMX_CPU_ACCELERATION to SSE2 for older i386 machines
- added openmpi package
- split doc, bash-completion into separate packages
* Tue Mar  5 2013 kkaempf@suse.com
- Update to 4.6.1
  Bugfix release
  - increased shared object major version to 8, #1147
  - updates to HTML manual, install guide, PDF manual, shell completions
    copious minor bug fixes
  - various build system upgrades and fixes #1143
  - new and enhanced error messages
  - fixes for AdResS bugs (neighbour list construction, flop accounting,
    multiple tf tables)
  - fixed PME timing counter issues #1125
  - fixed PME load balance reporting
  - fixed forcerec to work with tools like genion and g_disre #1136
  - various GPU performance enhancements
  - fixed sd integrator with OpenMP threading #1138
  - various minor fixes for interacting with CUDA for GPUs
  - fixes for g_tune_pme to cope with new mdrun behaviour and changed
    command-line options (for both g_tune_pme and mdrun)
  - more checks for system support for setting thread affinities
  - removed inter-flag dependency in g_order
  - fixed issues with free-energy pertubation soft-core and cut-offs #1146
  - fixed issues with md-vv + nose-hoover + (nstcalcenergy > nsttcouple)
    [#1129]
  - incorporated new changes from release 4.5.x branch
  - prevented building with icc 11.1 and SSE4.1 because of known problems
    [#1126]
  - adding warning about not building with icc version < 12 #1126
  - fixed bug sorting atoms with GPUs introduced since 4.6 #1153
  - fixed issues with automated download of regression tests #1150
  - fixed bug with DD cut-off check and PME dynamic load balancing #1169
* Mon Feb  4 2013 kkaempf@suse.com
- Update to 4.6
  New features
  - New Verlet non-bonded scheme which, by default, uses exact cut-off's
    and a buffered pair-list.
  - Multi-level hybrid parallelization (MPI + OpenMP + CUDA):
    full OpenMP multithreading with the Verlet scheme;
  - OpenMP mulitthreading for PME-only nodes with the group scheme;
    native GPU acceleration using CUDA (supporte NVIDIA hardware).
  - New x86 SIMD non-bonded kernels for the usual cut-off scheme, called
    group scheme and the new verlet scheme, use x86 SIMD intrinsics (no
    more assembly code):
    SSE2
    SSE4.1
    AVX-128-FMA (for AMD Bulldozer/Piledriver)
    AVX-256 (for Intel Sandy/Ivy Bridge)
  - Automated OpenMP thread count choice to use all available cores.
  - Automated CPU affinity setting: locking processes or threads to cores.
  - Automated PP-PME (task) load-balancing: balancing non-bonded force and
    PME mesh workload when the two are executed on different
    compute-resources (i.e CPU and GPU or different CPUs). This enables
    GPU-CPU and PP-PME process load balancing by shifting work from the
    mesh to the non-bonded calculation.
  - PPPM/P3M with analytical derivative at the same cost and with the same
    features as PME.
  - New, advanced free energy sampling techniques.
  - AdResS adaptive resolution simulation support.
  - Enforced rotation ("rotational pulling")
  - Build configuration now uses CMake, configure+autoconf/make no longer
    supported. (The CMake build system features with a lot of automation
    and cleverness under the hood and we know that the it might not always
    prove to be as rock-solid as the old one. However, far more advanced
    and complex, so bear with us while we iron out issues that come up
    along the way.)
  - g_hbond now utilizes OpenMP.
  Plus plenty of bug fixes.
* Mon Jun  4 2012 toddrme2178@gmail.com
- Clean up spec file
* Wed Sep 21 2011 kkaempf@suse.com
- Clean up spec file
- Update to 4.5.5
  - Improved pdb2gmx -chainsep option and reintroduced the -merge option.
  - Fixed mdrun file appending truncating files to 0 bytes when
    continuation runs stopped before writing new output.
  - Fixed COM pulling with multiple constraints checking the
    convergence of one constraint instead of all.
  - Fixed some dihedrals in sugars in Gromos53a5/6 working on the
    wrong atoms.
  - AmberGS force field is now based on Amber94 instead of Amber96.
  - Moved hydrogens in Charmm27 protein termini to separate charge
    groups and added ACE and CT3 residue types.
  - Many small fixes which avoid termination with fatal errors or
    crashes in mdrun and tools.
  - Many small updates to the manual pages of programs.
* Tue Mar 22 2011 kkaempf@novell.com
- Update to 4.5.4
  - Fixed pdb2gmx picking up force field from local instead of
    library directory
  - Made pdb2gmx vsite generation work again for certain His
    namings.
  - Fixed incorrect virial and pressure averages with certain
    nst... values (instantaneous values correct)
  - Fixed incorrect cosine viscosity output
  - New -multidir alternative for mdrun -multi option
  - Several minor fixes in analysis tools
  - Several updates to the program documentation
* Wed Nov 10 2010 kkaempf@novell.com
- Update to 4.5.3
  - Double precision energy file reading
  - CHARMM and GB issues
  - Support for Altivec (PowerPC) with CMake
  - Running binaries within the CMake build tree is now possible
  - Various other fixes
* Thu Oct  7 2010 kkaempf@novell.com
- Update to 4.5.1
  - fix bnc#642828 (CVE-2010-4001: Insecure use of LD_LIBRARY_PATH)
  See http://www.gromacs.org/About_Gromacs/Release_Notes/Version_4.5
  for a full list of changes
  - 2D decomposition support for PME: improved load balancing with
    up to 40%% overall performance improvement for large systems.
  - Memory usage is improved for very large systems, allowing
    simulations of >100 million atoms.
  - Running on multi-core nodes now automatically uses thread-
    based parallelization.
  - GPU computing support
  - Check-pointing is made more secure:MD5sum are used to verify
    that all files are correctly in-place before a simulation is
    appended. Output file appending at continuation is turned on
    by default
  - Full Cmake support. Autoconf/automake will be deprecated after
    the final 4.5 release!
  - Full support for 7 AMBER force fields
  - Support for CHARMM27, including cmap for dihedrals
  - Efficient Generalized-Born implicit solvent support including
    the Still/HCT/OBC-models to compute the Born radii, a novel way
    of tabulating the generalized Born-interaction formula for
    greater speed, and optimized SSE-routines for both cut-off and
    all-vs-all simulations.
  - Support for nucleic acid simulations
  - Support for Velocity-Verlet integrators for reversible T- and
    P-coupling; MTTK pressure control integrators; Nose-Hoover
    chains
  - Support for Bennett acceptance ratio (BAR) free energy
    calculations
  - Decoupling group setup for free energy
  - File formats: All GROMACS tools can now read any VMD supported
    trajectory format, without converting trajectory first. (VMD
    is required)
  - g_rdf was a little bit enhanced that structure factors can be
    calculated for any system, by supplying the necessary data via
    sfactor.dat. Most of the common atomtypes are already contained,
    but everybody who needs more freedom can enhance the table
  - Library support for "dynamic index groups" based on textual
    selections (experimental feature). See the tool g_select, the
    included template.c, or Doxygen documentation for information on
    how to write analysis tools using the library. Existing tools
    have not (yet) been converted.
  - g_tune_pme: For a given number of processes or threads this tool
    systematically times mdrun with various numbers of PME-only nodes
    and determines which setting is fastest. It also checks whether
    performance can be enhanced by shifting load between the real and
    the reciprocal space part of the Ewald sum.
  - g_membed: a very convenient utility for embedding membrane
    proteins into equilibrated lipid bilayers
* Sat May 22 2010 cristian.rodriguez@opensuse.org
- read "/dev/urandom" instead of /dev/random
* Sat Jun 20 2009 coolo@novell.com
- fix build with automake 1.11
* Fri Jan  9 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Tue Oct  7 2008 kkaempf@suse.de
- Fix buffer overflow (gcc static detection) in calcmu.c
* Sun Oct 15 2006 schwab@suse.de
- Use install-exec-hook instead of install-hook.
- Use AM_PROG_AS.
* Wed Jul 19 2006 kkaempf@suse.de
- update to 3.3.1
  see http://www.gromacs.org for a complete list of changes.
* Mon Jun 19 2006 schwab@suse.de
- Set datadir.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 ro@suse.de
- added .so symlink to filelist
* Wed Aug 11 2004 kkaempf@suse.de
- bugfix update to 3.2.1
* Mon Feb 23 2004 kkaempf@suse.de
- rename 'disco' to 'g_disco' to avoid nameclash with package mono
- build with -fno-strict-aliasing
- return value from main()
* Tue Feb 17 2004 kkaempf@suse.de
- remove obsolete libtool from "configure.ac".
- use proper automake syntax in "acinclude.m4".
- add missing FF.dat as advised on gromacs-users mailing list.
* Tue Feb  3 2004 kkaempf@suse.de
- update to 3.2
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Fri Jun 13 2003 kukuk@suse.de
- Add missing directories to filelist and fix permissions
* Wed Nov 20 2002 ro@suse.de
- work around automake problem
* Fri Nov 15 2002 uli@suse.de
- removed lesstif from neededforbuild (not used)
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xf86 xshared xdevel> to <x-devel-packages>
* Tue Oct 29 2002 ro@suse.de
- removed own libtool hacks from acinclude.m4
* Mon Jul 29 2002 kkaempf@suse.de
- Initial version 3.1.4
